@@ -14,13 +14,14 @@ set(
   '_search_tabs'  => [],
   '_device_tabs'  => [],
   '_admin_tasks'  => {},
+  '_admin_order'  => [],
   '_reports_menu' => {},
   '_reports' => {},
-  '_report_order' => [qw/Device Port IP Node VLAN Network Wireless/],
+  '_report_order' => [qw/Device Port IP Node VLAN Network Wireless/, 'My Reports'],
 );
 
 # this is what Dancer::Template::TemplateToolkit does by default
-config->{engines}->{template_toolkit}->{INCLUDE_PATH} ||= [ setting('views') ];
+config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} ||= [ setting('views') ];
 
 register 'register_template_path' => sub {
   my ($self, $path) = plugin_args(@_);
@@ -29,9 +30,8 @@ register 'register_template_path' => sub {
       return error "bad template path to register_template_paths";
   }
 
-  unshift
-    @{ config->{engines}->{template_toolkit}->{INCLUDE_PATH} },
-    $path, dir($path, 'views')->stringify;
+  unshift @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
+       dir($path, 'views')->stringify;
 };
 
 sub _register_include {
@@ -123,6 +123,7 @@ register 'register_admin_task' => sub {
       return error "bad config to register_admin_task";
   }
 
+  push @{ setting('_admin_order') }, $config->{tag};
   setting('_admin_tasks')->{ $config->{tag} } = $config;
 };
 
@@ -168,15 +169,23 @@ register 'register_report' => sub {
       return error "bad config to register_report";
   }
 
-  foreach my $item (@{setting('_reports_menu')->{ $config->{category} }}) {
-      if ($item eq $config->{tag}) {
-          setting('_reports')->{$config->{tag}} = $config;
-          return;
-      }
+  if (0 == scalar grep {$_ eq $config->{tag}}
+                       @{setting('_reports_menu')->{ $config->{category} }}) {
+      push @{setting('_reports_menu')->{ $config->{category} }}, $config->{tag};
   }
 
-  push @{setting('_reports_menu')->{ $config->{category} }}, $config->{tag};
-  setting('_reports')->{$config->{tag}} = $config;
+  foreach my $tag (@{setting('_reports_menu')->{ $config->{category} }}) {
+      if ($config->{tag} eq $tag) {
+          setting('_reports')->{$tag} = $config;
+
+          foreach my $rconfig (@{setting('reports')}) {
+              if ($rconfig->{tag} eq $tag) {
+                  setting('_reports')->{$tag}->{'rconfig'} = $rconfig;
+                  last;
+              }
+          }
+      }
+  }
 };
 
 register_plugin;
